==> hbase-2.3.7-src.tar.gz: hbase-2.3.7/hbase-server/src/main/java/org/apache/hadoop/hbase/wal/BoundedEntryBuffers.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.wal;

import org.apache.yetus.audience.InterfaceAudience;

/**
 * Used for {@link BoundedRecoveredEditsOutputSink}. The core part of limiting opening writers is it
 * doesn't return chunk only if the heap size is over maxHeapUsage. Thus it doesn't need to create
 * a writer for each region during splitting. The returned {@link EntryBuffers.RegionEntryBuffer}
 * will be write to recovered edits file and close the writer immediately.
 * See {@link BoundedRecoveredEditsOutputSink#append(EntryBuffers.RegionEntryBuffer)} for more
 * details.
 */
@InterfaceAudience.Private
public class BoundedEntryBuffers extends EntryBuffers {

  public BoundedEntryBuffers(WALSplitter.PipelineController controller, long maxHeapUsage) {
    super(controller, maxHeapUsage);
  }

  @Override
  synchronized RegionEntryBuffer getChunkToWrite() {
    if (totalBuffered < maxHeapUsage) {
      return null;
    }
    return super.getChunkToWrite();
  }
}

==> hbase-2.6.3-src.tar.gz: hbase-2.6.3/hbase-server/src/main/java/org/apache/hadoop/hbase/wal/BoundedEntryBuffers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.wal;

import org.apache.yetus.audience.InterfaceAudience;

/**
 * Used for {@link BoundedRecoveredEditsOutputSink}. The core part of limiting opening writers is it
 * doesn't return chunk only if the heap size is over maxHeapUsage. Thus it doesn't need to create a
 * writer for each region during splitting. The returned {@link EntryBuffers.RegionEntryBuffer} will
 * be write to recovered edits file and close the writer immediately. See
 * {@link BoundedRecoveredEditsOutputSink#append(EntryBuffers.RegionEntryBuffer)} for more details.
 */
@InterfaceAudience.Private
public class BoundedEntryBuffers extends EntryBuffers {

  public BoundedEntryBuffers(WALSplitter.PipelineController controller, long maxHeapUsage) {
    super(controller, maxHeapUsage);
  }

  @Override
  synchronized RegionEntryBuffer getChunkToWrite() {
    if (totalBuffered < maxHeapUsage) {
      return null;
    }
    return super.getChunkToWrite();
  }
}
